form_submit
open | /demo/form_submit.html |
type | name | John Foo
type | address | Bar street, 12
type | city | Foobar
select | country | label=USA
type | telephone | 100
click | submit |
waitForTextPresent | Async saved: |
verifyTextPresent | 100 |
verifyTextPresent | Foobar |
verifyTextPresent | USA |
verifyTextPresent | John Foo |
verifyTextPresent | Bar street, 12 |
type | name | Brigitte Bardou
type | address | Cool street
select | country | label=USA
select | country | label=Norway
type | city | Southway
type | telephone | dring
click | submit |
waitForTextPresent | dring |
verifyTextPresent | Async saved: |
verifyTextPresent | dring |
verifyTextPresent | Southway |
verifyTextPresent | Norway |
verifyTextPresent | Brigitte Bardou |
verifyTextPresent | Cool street |